``zope.securitypolicy`` README
==============================

This package provides an useful security policy for Zope3. It's the
default security policy used in "zope3 the application" and many other
zope-based projects.
